<p align="center">
  <img src="https://i2.wp.com/googlediscovery.com/wp-content/uploads/google-developers.png" alt="Logo" title="Aiogoogle" height="150" width="200"/>
  <p align="center">
    <a href="https://github.com/omarryhan/aiogoogle/actions?query=workflow%3ACI"><img alt="Build Status" src="https://github.com/omarryhan/aiogoogle/workflows/CI/badge.svg"></a>
    <a href="https://github.com/omarryhan/aiogoogle"><img alt="Software License" src="https://img.shields.io/badge/license-MIT-brightgreen.svg?style=flat-square"></a>
    <a href="https://github.com/python/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg" /></a>
    <a href="https://pepy.tech/badge/aiogoogle"><img alt="Downloads" src="https://pepy.tech/badge/aiogoogle"></a>
    <a href="https://pepy.tech/badge/aiogoogle/month"><img alt="Monthly Downloads" src="https://pepy.tech/badge/aiogoogle/month"></a>
  </p>
</p>

# Aiogoogle

**Async** Google API client

Aiogoogle makes it possible to access most of Google's public APIs which include:

- Google Calendar API
- Google Drive API
- Google Contacts API
- Gmail API
- Google Maps API
- Youtube API
- Translate API
- Google Sheets API
- Google Docs API
- Gogle Analytics API
- Google Books API
- Google Fitness API
- Google Genomics API
- Google Cloud Storage
- Kubernetes Engine API
- And [more](https://developers.google.com/apis-explorer)

## Documentation 📑

You can find the documentation [here](https://aiogoogle.readthedocs.io/en/latest/#).

